package nl.kallestruik.darena.types.arena

import org.bukkit.configuration.ConfigurationSection
import javax.naming.ConfigurationException
import nl.kallestruik.darena.types.ConfigSaveable
import nl.kallestruik.darena.types.ConfigLoadable
import nl.kallestruik.darena.util.ConfigHelper
import nl.kallestruik.darena.util.Logger

data class ArenaCheckpoint(
    val label: String,
    val lower: ArenaLocation,
    val upper: ArenaLocation,
    val spawn: String,
): ConfigSaveable {
    override fun save(section: ConfigurationSection) {
        Logger.trace(ArenaCheckpoint::class, "save(section: ${section.currentPath})")
        section.set("label", label)
        lower.save(ConfigHelper.getOrCreateSection(section, "lower"))
        upper.save(ConfigHelper.getOrCreateSection(section, "upper"))
        section.set("spawn", spawn)
    }

    companion object: ConfigLoadable<ArenaCheckpoint> {
        override fun load(section: ConfigurationSection): ArenaCheckpoint {
            Logger.trace(ArenaCheckpoint::class, "load(section: ${section.currentPath})")
            return ArenaCheckpoint(
                section.name,
                ArenaLocation.load(section.getConfigurationSection("lower")!!),
                ArenaLocation.load(section.getConfigurationSection("upper")!!),
                section.getString("spawn") ?: throw ConfigurationException("Could not find required field spawn in '${section.currentPath}'")
            )
        }
    }
}
