package nl.kallestruik.darena.types.arena

import nl.kallestruik.darena.util.ConfigHelper
import nl.kallestruik.darena.types.ConfigSaveable
import nl.kallestruik.darena.types.ConfigLoadable
import org.bukkit.Material
import org.bukkit.configuration.ConfigurationSection

data class ArenaItem(
    val material: Material = Material.AIR,
    val amount: Int = 1,
    val enchantments: List<ArenaEnchantment> = listOf(),
    val unbreakable: Boolean = false,
): ConfigSaveable {
    override fun save(section: ConfigurationSection) {
        section.set("material", material.toString())
        section.set("amount", amount)
        ConfigHelper.saveList(ConfigHelper.getOrCreateSection(section, "enchantments"), enchantments, ArenaEnchantment)
        section.set("unbreakable", unbreakable)
    }

    companion object: ConfigLoadable<ArenaItem> {
        override fun load(section: ConfigurationSection): ArenaItem {
            val enchantments = section.getConfigurationSection("enchantments")?.let {
                ArenaEnchantment.loadList(it)
            } ?: listOf()

            return ArenaItem(
                ConfigHelper.matchMaterial(section.getString("material")!!),
                section.getInt("amount", 1),
                enchantments,
                section.getBoolean("unbreakable", false)
            )
        }
    }
}
