package nl.kallestruik.darena.types.arena

import org.bukkit.configuration.ConfigurationSection
import nl.kallestruik.darena.util.ConfigHelper
import nl.kallestruik.darena.types.ConfigSaveable
import nl.kallestruik.darena.types.ConfigLoadable

data class ArenaLoadout(
    val name: String,
    val hotbar: List<ArenaItem>,
    val armor: List<ArenaItem>,
    val offhand: ArenaItem,
): ConfigSaveable {
    override fun save(section: ConfigurationSection) {
        ConfigHelper.saveList(ConfigHelper.getOrCreateSection(section, "hotbar"), hotbar)
        ConfigHelper.saveList(ConfigHelper.getOrCreateSection(section, "armor"), armor)
        offhand.save(ConfigHelper.getOrCreateSection(section, "offhand"))
    }

    companion object : ConfigLoadable<ArenaLoadout> {
        override fun load(section: ConfigurationSection): ArenaLoadout {

            val hotbar = section.getConfigurationSection("hotbar")?.let {
                ArenaItem.loadList(it)
            }?: listOf()

            val armor = section.getConfigurationSection("armor")?.let {
                ArenaItem.loadList(it)
            }?: listOf()

            val offhand = section.getConfigurationSection("offhand")?.let {
                ArenaItem.load(it)
            }?: ArenaItem()

            return ArenaLoadout(
                section.name,
                hotbar,
                armor,
                offhand,
            )
        }
    }
}
