package nl.kallestruik.darena.types.arena

import nl.kallestruik.darena.arenas.world.ArenaWorld
import nl.kallestruik.darena.util.ConfigHelper
import nl.kallestruik.darena.types.ConfigSaveable
import nl.kallestruik.darena.types.ConfigLoadable
import org.bukkit.Location
import org.bukkit.configuration.ConfigurationSection
import org.bukkit.entity.Player

data class ArenaSpawn(
    val label: String,
    val x: Double,
    val y: Double,
    val z: Double,
    val yaw: Float,
    val pitch: Float,
    val loadout: String
): ConfigSaveable {
    fun spawn(world: ArenaWorld, player: Player) {
        player.teleport(Location(world.world, x, y, z, yaw, pitch))
    }

    override fun save(section: ConfigurationSection) {
        section.set("x", x)
        section.set("y", y)
        section.set("z", z)
        section.set("yaw", yaw.toDouble())
        section.set("pitch", pitch.toDouble())
        section.set("loadout", loadout)
    }

    companion object: ConfigLoadable<ArenaSpawn> {
        override fun load(section: ConfigurationSection): ArenaSpawn {
            return ArenaSpawn(
                section.name,
                section.getDouble("x"),
                section.getDouble("y"),
                section.getDouble("z"),
                section.getDouble("yaw").toFloat(),
                section.getDouble("pitch").toFloat(),
                section.getString("loadout")!!
            )
        }
    }
}
